@@ -1,5 +1,5 @@
 {- |
-Copyright: (c) 2020 Kowainik
+Copyright: (c) 2022 Kowainik
 SPDX-License-Identifier: BSD-3-Clause
 Maintainer: Kowainik <xrom.xkov@gmail.com>
 
@@ -7,9 +7,9 @@ Cabal-only example with all integrations
 -}
 
 module CabalFull
-       ( someFunc
-       ) where
+    ( projectName
+    ) where
 
 
-someFunc :: IO ()
-someFunc = putStrLn ("someFunc" :: String)
+projectName :: String
+projectName = "cabal-full"
