@@ -399,6 +399,7 @@ newP = do
     stack <- stackP
     preludePack <- optional preludePackP
     preludeMod  <- optional preludeModP
+    branchName <- optional branchP
     with    <- optional withP
     without <- optional withoutP
 
@@ -408,6 +409,7 @@ newP = do
             , cCabal = cabal
             , cStack = stack
             , cNoUpload = Any $ noUpload || isOffline newOptsConnectMode
+            , cBranchName = Last branchName
             }
         , ..
         }
@@ -569,6 +571,13 @@ stackP = flag Idk Yes $ mconcat
     , help "Stack support for the project"
     ]
 
+branchP :: Parser Text
+branchP = strOption $ mconcat
+    [ long "branch"
+    , metavar "BRANCH_NAME"
+    , help "Default branch name for the project (e.g. main, master)"
+    ]
+
 ----------------------------------------------------------------------------
 -- Beauty util
 ----------------------------------------------------------------------------
