@@ -1,27 +1,29 @@
 {- |
-Copyright: (c) 2017-2020 Kowainik
-SPDX-License-Identifier: MPL-2.0
-Maintainer: Kowainik <xrom.xkov@gmail.com>
+Module                  : Summoner.License
+Copyright               : (c) 2017-2026 Kowainik
+SPDX-License-Identifier : MPL-2.0
+Maintainer              : Kowainik <xrom.xkov@gmail.com>
+Stability               : Stable
+Portability             : Portable
 
 Data types that represent license names and license content and functions
 to work with them.
 -}
 
 module Summoner.License
-       ( LicenseName(..)
-       , License(..)
-       , customizeLicense
-       , githubLicenseQueryNames
-       , parseLicenseName
-       , fetchLicense
-       , fetchLicenseCustom
-       , licenseShortDesc
-       , showLicenseWithDesc
-       ) where
+    ( LicenseName (..)
+    , License (..)
+    , customizeLicense
+    , githubLicenseQueryNames
+    , parseLicenseName
+    , fetchLicense
+    , fetchLicenseCustom
+    , licenseShortDesc
+    , showLicenseWithDesc
+    ) where
 
 import Colourista (errorMessage)
-import Data.Aeson (FromJSON (..), decodeStrict, withObject, (.:))
-import Relude.Extra.Enum (inverseMap)
+import Data.Aeson.Micro (FromJSON (..), decodeStrict, withObject, (.:))
 import Shellmet (($|))
 
 import qualified Data.Text as T
